==> spip_4.0.4.orig.tar.xz: ecrire/lang/public_oc_ni_la.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=oc_ni_la
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Acuelh dau sit', # MODIF
	'articles' => 'Articles',
	'articles_auteur' => 'Articles d’aquel autor',
	'articles_populaires' => 'Lu articles mai populars',
	'articles_rubrique' => 'Articles d’aquela rubrica',
	'aucun_article' => 'I a minga d’article a aquela adreiça ',
	'aucun_auteur' => 'I a minga d’autor a aquela adreiça ',
	'aucun_site' => 'I a minga de sit a aquela adreiça ',
	'aucune_breve' => 'I a minga de brèva a aquela adreiça ',
	'aucune_rubrique' => 'I a minga de rubrica a aquela adreiça ',
	'autres_breves' => 'Autri brèvas',
	'autres_groupes_mots_clefs' => 'Autres grops de mots clau',
	'autres_sites' => 'Autres sits',

	// B
	'bonjour' => 'Bònjorn',

	// C
	'commenter_site' => 'Comentar aqueu sit',

	// D
	'date' => 'Data',
	'dernier_ajout' => 'Darrier apondon',
	'dernieres_breves' => 'Darrieri brèvas',
	'derniers_articles' => 'Darriers articles',
	'derniers_commentaires' => 'Darriers comentaris',
	'derniers_messages_forum' => 'Darriers messatges publicats dins lu forums',

	// E
	'edition_mode_texte' => 'Edicion en mòde tèxt de',
	'en_reponse' => 'En respòsta a:',
	'en_resume' => 'En resumit',
	'envoyer_message' => 'Mandar un messatge',
	'espace_prive' => 'Espaci privat',

	// H
	'hierarchie_site' => 'Ierarquia dau sit',

	// J
	'jours' => 'jorns',

	// M
	'meme_auteur' => 'Dau meteis autor',
	'meme_rubrique' => 'Dins la meteissa rubrica',
	'memes_auteurs' => 'Dei meteis autors',
	'message' => 'Messatge',
	'messages_forum' => 'Messatges de forum', # MODIF
	'messages_recents' => 'Lu messatges de forums mai recents',
	'mots_clefs' => 'Mots clau',
	'mots_clefs_meme_groupe' => 'Mots clau dins lo meteis grop',

	// N
	'navigation' => 'Navigacion',
	'nom' => 'Nom',
	'nouveautes' => 'Li novetats',
	'nouveautes_web' => 'Novetats sobre lo web',
	'nouveaux_articles' => 'Articles nòus',
	'nouvelles_breves' => 'Brèvas nòvi',

	// P
	'page_precedente' => 'pàgina precedenta',
	'page_suivante' => 'pàgina seguenta',
	'par_auteur' => 'per ',
	'participer_site' => 'Podètz participar a la vida d’aqueu sit e prepauar lu articles vòstres en v’inscrivent çai sota. Recebretz sus lo còup un e-mail que v’indicarà lu vòstres còdes per accedir a l’espaci privat dau sit.',
	'plan_site' => 'Plan dau sit',
	'popularite' => 'Popularitat',
	'poster_message' => 'Postar un messatge',
	'proposer_site' => 'Podètz prepauar un sit d’apondre a aquesta rubrica:',

	// R
	'repondre_article' => 'Respòndre a aquel article',
	'repondre_breve' => 'Respòndre a aquela brèva',
	'resultats_recherche' => 'Resultats de la cèrca',
	'retour_debut_forums' => 'Retorn au començament dei forums',
	'rubrique' => 'Rubrica',
	'rubriques' => 'Rubricas',

	// S
	'signatures_petition' => 'Signaturas',
	'site_realise_avec_spip' => 'Sit realizat emb SPIP',
	'sites_web' => 'Sits web',
	'sous_rubriques' => 'Sosrubricas',
	'suite' => 'seguda',
	'sur_web' => 'Sobre lo web',
	'syndiquer_rubrique' => 'Sindicar aquela rubrica',
	'syndiquer_site' => 'Sindicar tot lo sit',

	// T
	'texte_lettre_information' => 'Vètz la letra d’informacion dau sit',
	'texte_lettre_information_2' => 'Aquela letra recensa lu articles e brèvas publicats despí', # MODIF

	// V
	'ver_imprimer' => 'Version d’estampar',
	'voir_en_ligne' => 'Veètz en linha',
	'voir_squelette' => 'telecargar l’esqueleta d’aquela pàgina'
);

==> spip_4.4.9+dfsg.orig.tar.xz: ecrire/lang/public_oc_ni_la.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=oc_ni_la
// ** ne pas modifier le fichier **

return [

	// A
	'accueil_site' => 'Acuelh dau sit', # MODIF
	'articles' => 'Articles',
	'articles_auteur' => 'Articles d’aquel autor',
	'articles_populaires' => 'Lu articles mai populars',
	'articles_rubrique' => 'Articles d’aquela rubrica',
	'aucun_article' => 'I a minga d’article a aquela adreiça ',
	'aucun_auteur' => 'I a minga d’autor a aquela adreiça ',
	'aucun_site' => 'I a minga de sit a aquela adreiça ',
	'aucune_breve' => 'I a minga de brèva a aquela adreiça ',
	'aucune_rubrique' => 'I a minga de rubrica a aquela adreiça ',
	'autres_breves' => 'Autri brèvas',
	'autres_groupes_mots_clefs' => 'Autres grops de mots clau',
	'autres_sites' => 'Autres sits',

	// B
	'bonjour' => 'Bònjorn',

	// C
	'commenter_site' => 'Comentar aqueu sit',

	// D
	'date' => 'Data',
	'dernier_ajout' => 'Darrier apondon',
	'dernieres_breves' => 'Darrieri brèvas',
	'derniers_articles' => 'Darriers articles',
	'derniers_commentaires' => 'Darriers comentaris',
	'derniers_messages_forum' => 'Darriers messatges publicats dins lu forums',

	// E
	'edition_mode_texte' => 'Edicion en mòde tèxt de',
	'en_reponse' => 'En respòsta a:',
	'en_resume' => 'En resumit',
	'envoyer_message' => 'Mandar un messatge',
	'espace_prive' => 'Espaci privat',

	// H
	'hierarchie_site' => 'Ierarquia dau sit',

	// J
	'jours' => 'jorns',

	// M
	'meme_auteur' => 'Dau meteis autor',
	'meme_rubrique' => 'Dins la meteissa rubrica',
	'memes_auteurs' => 'Dei meteis autors',
	'message' => 'Messatge',
	'messages_forum' => 'Messatges de forum', # MODIF
	'messages_recents' => 'Lu messatges de forums mai recents',
	'mots_clefs' => 'Mots clau',
	'mots_clefs_meme_groupe' => 'Mots clau dins lo meteis grop',

	// N
	'navigation' => 'Navigacion',
	'nom' => 'Nom',
	'nouveautes' => 'Li novetats',
	'nouveautes_web' => 'Novetats sobre lo web',
	'nouveaux_articles' => 'Articles nòus',
	'nouvelles_breves' => 'Brèvas nòvi',

	// P
	'page_precedente' => 'pàgina precedenta',
	'page_suivante' => 'pàgina seguenta',
	'par_auteur' => 'per ',
	'participer_site' => 'Podètz participar a la vida d’aqueu sit e prepauar lu articles vòstres en v’inscrivent çai sota. Recebretz sus lo còup un e-mail que v’indicarà lu vòstres còdes per accedir a l’espaci privat dau sit.',
	'plan_site' => 'Plan dau sit',
	'popularite' => 'Popularitat',
	'poster_message' => 'Postar un messatge',
	'proposer_site' => 'Podètz prepauar un sit d’apondre a aquesta rubrica:',

	// R
	'repondre_article' => 'Respòndre a aquel article',
	'repondre_breve' => 'Respòndre a aquela brèva',
	'resultats_recherche' => 'Resultats de la cèrca',
	'retour_debut_forums' => 'Retorn au començament dei forums',
	'rubrique' => 'Rubrica',
	'rubriques' => 'Rubricas',

	// S
	'signatures_petition' => 'Signaturas',
	'site_realise_avec_spip' => 'Sit realizat emb SPIP',
	'sites_web' => 'Sits web',
	'sous_rubriques' => 'Sosrubricas',
	'suite' => 'seguda',
	'sur_web' => 'Sobre lo web',
	'syndiquer_rubrique' => 'Sindicar aquela rubrica',
	'syndiquer_site' => 'Sindicar tot lo sit',

	// T
	'texte_lettre_information' => 'Vètz la letra d’informacion dau sit',
	'texte_lettre_information_2' => 'Aquela letra recensa lu articles e brèvas publicats despí', # MODIF

	// V
	'ver_imprimer' => 'Version d’estampar',
	'voir_en_ligne' => 'Veètz en linha',
	'voir_squelette' => 'telecargar l’esqueleta d’aquela pàgina',
];
